@@ -27,7 +27,7 @@ class GenericAPI:
 
     Parameters
     ----------
-    auth : auth.Authorization
+    auth : hyperthought.auth authentication class
         Authorization manager for access to HyperThought™ over OIDC.
     """
 
