@@ -26,9 +26,6 @@ class MetatronAPI(GenericAPI):
         curried_request = partial(
             requests.get,
             url=f'{self._base_url}/api/metatron/parsers/',
-            headers=self._auth.get_headers(),
-            cookies=self._auth.get_cookies(),
-            verify=self._auth.verify,
         )
         r = self.attempt_api_call(curried_request=curried_request)
 
