@@ -900,8 +900,9 @@ class WorkflowAPI(GenericAPI):
         username = self._auth.get_username()
         create_date = datetime.now().isoformat()
         payload = {
-            'xml': xml_,
             'pk': workflow.id,
+            'client_id': workflow.client_id,
+            'xml': xml_,
             'name': workflow.name,
             'creator': username,
             'created': create_date,
@@ -911,7 +912,6 @@ class WorkflowAPI(GenericAPI):
             'process_type': workflow.type,
             'permissions': permissions,
             'children': [child.id for child in workflow.children],
-            'client_id': workflow.client_id,
             'predecessors': [
                 predecessor.id for predecessor in workflow.predecessors
             ],
@@ -1027,6 +1027,15 @@ class WorkflowAPI(GenericAPI):
             ],
         }
 
+        if process.notes:
+            payload['notes'] = process.notes
+
+        if process.assignee:
+            payload['assignee'] = process.assignee
+
+        if process.due_date:
+            payload['dueDate'] = process.due_date
+
         url = f"{self._base_url}/api/workflow/process/"
         curried_request = partial(
             requests.post,
@@ -1224,3 +1233,103 @@ class WorkflowAPI(GenericAPI):
 
         # Update the parent canvas to display the link.
         self.redraw_canvas(workflow_id=source_document['parentProcess'])
+
+    def complete(self, element_id):
+        """
+        Complete an active workflow element (process or decision).
+
+        Parameters
+        ----------
+        element_id : str
+            The id of the workflow element to be completed.
+        """
+        if not isinstance(element_id, str):
+            raise ValueError('workflow_id must be a string')
+
+        curried_request = partial(
+            requests.post,
+            url=(
+                f'{self._base_url}/'
+                f'api/workflow/process/{element_id}/complete/'
+            )
+        )
+
+        r = self.attempt_api_call(curried_request)
+
+        if r.status_code >= ERROR_THRESHOLD:
+            # NOTE:  This method will throw an exception.
+            self._report_api_error(response=r)
+
+        return r.json()
+
+    def execute_workflow(self, template_id, workflow_name):
+        """
+        Execute a workflow template.
+
+        The template workflow will be copied (all elements and subworkflows)
+        and made into an "Active" workflow.
+
+        Parameters
+        ----------
+        template_id : str
+            The id of the workflow template to be executed.
+
+        workflow_name: str
+            The desired name for the workflow once it's executed.
+        """
+        if not isinstance(template_id, str):
+            raise ValueError('template_id must be a string')
+
+        if not isinstance(workflow_name, str):
+            raise ValueError('workflow_name must be a string')
+
+        payload = {
+            'workflowName': f'{workflow_name}'
+        }
+
+        curried_request = partial(
+            requests.post,
+            url=(
+                f'{self._base_url}/'
+                f'api/workflow/process/{template_id}/execute/'
+            ),
+            json=payload
+        )
+
+        r = self.attempt_api_call(curried_request)
+
+        if r.status_code >= ERROR_THRESHOLD:
+            # NOTE:  This method will throw an exception.
+            self._report_api_error(response=r)
+
+        return r.json()
+
+    def accept(self, element_id):
+        """
+        Accept a workflow element (process or decision).
+
+        The element will be assigned to the user calling the method.
+
+        Parameters
+        ----------
+        element_id : str
+            The id of the workflow element to be accepted.
+        """
+        if not isinstance(element_id, str):
+            raise ValueError('workflow_id must be a string')
+
+        curried_request = partial(
+            requests.post,
+            url=(
+                f'{self._base_url}/'
+                f'api/workflow/process/{element_id}/accept/'
+            )
+        )
+
+        r = self.attempt_api_call(curried_request)
+
+        if r.status_code >= ERROR_THRESHOLD:
+            # NOTE:  This method will throw an exception.
+            self._report_api_error(response=r)
+
+        return r.json()
