@@ -25,6 +25,8 @@ from ._genericjson import GenericJson
 from ._midas import MidasStressStrain
 from ._nsidat import NorthStarImageData
 from ._fei_tiff import FeiTiff
+from ._eids import EIDS
+from ._picard import Picard
 # hyperspy removed for now.  Email sent to Andrew Sharits on 10/28/21 to see
 # if it is still of interest.
 # from ._hyperspy import GenericHyperSpy
@@ -38,6 +40,8 @@ PARSERS = {
     'NorthStarImageData': NorthStarImageData,
     'FeiTiff': FeiTiff,
     'GenericJson': GenericJson,
+    'EidsLayerNumber' : EIDS,
+    'Picard': Picard,
     # 'GenericHyperSpy': GenericHyperSpy,
 }
 
